# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: pymammotion/proto/mctrl_pept.proto
# plugin: python-betterproto
from dataclasses import dataclass


import betterproto


@dataclass
class PerceptionObstaclesT(betterproto.Message):
    label: int = betterproto.int32_field(1)
    num: int = betterproto.int32_field(2)
    points_x: list[int] = betterproto.int32_field(3)
    points_y: list[int] = betterproto.int32_field(4)


@dataclass
class PerceptionObstaclesVisualizationT(betterproto.Message):
    is_heart_beat: int = betterproto.int32_field(1)
    num: int = betterproto.int32_field(2)
    obstacles: list["PerceptionObstaclesT"] = betterproto.message_field(3)
    timestamp: float = betterproto.double_field(4)
    scale: float = betterproto.float_field(5)


@dataclass
class PerceptionUniversalBuffT(betterproto.Message):
    perception_type: int = betterproto.int32_field(1)
    perception_len: int = betterproto.int32_field(2)
    universal_buff: list[int] = betterproto.int64_field(3)


@dataclass
class MctlPept(betterproto.Message):
    perception_obstacles_visualization: "PerceptionObstaclesVisualizationT" = (
        betterproto.message_field(1, group="SubPeptMsg")
    )
    perception_universal_buff: "PerceptionUniversalBuffT" = betterproto.message_field(
        2, group="SubPeptMsg"
    )
